http library

Functions

fetchOhttpKeys({required String ohttpRelayUrl, required String directoryUrl, Uint8List? certificate, Uint8List? relayCertificate, Duration timeout = const Duration(seconds: 10)}) Future<OhttpKeys>
Fetches the OHTTP keys from a payjoin directory through an OHTTP relay proxy so the directory never observes the client IP address.