Address class

Constructors

Address(String address, Network network)
Address.fromScript(Script script, Network network)
Address.lift(Pointer<Void> ptr)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
isValidForNetwork(Network network) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scriptPubkey() Script
toQrUri() String
toString() String
A string representation of this object.
inherited
uniffiClonePointer() Pointer<Void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocationSize(Address value) int
lower(Address value) Pointer<Void>
read(Uint8List buf) LiftRetVal<Address>
write(Address value, Uint8List buf) int