Amount class
Constructors
- Amount.fromBtc(double btc)
- Amount.fromSat(int sat)
-
Amount.lift(Pointer<
Void> ptr) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBtc(
) → double -
toSat(
) → int -
toString(
) → String -
A string representation of this object.
inherited
-
uniffiClonePointer(
) → Pointer< Void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited