FeeRate class

Constructors

FeeRate.fromSatPerKwu(int satPerKwu)
FeeRate.fromSatPerVb(int satPerVb)
FeeRate.lift(Pointer<Void> ptr)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSatPerKwu() int
toSatPerVbCeil() int
toSatPerVbFloor() int
toString() String
A string representation of this object.
inherited
uniffiClonePointer() Pointer<Void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocationSize(FeeRate value) int
lower(FeeRate value) Pointer<Void>
read(Uint8List buf) LiftRetVal<FeeRate>
write(FeeRate value, Uint8List buf) int