FfiConverter<D, F> class abstract

Implementers

Constructors

FfiConverter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lift(F value) → D
lower(D value) → F
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(ByteData buffer, int offset) → D
size(D value) int
toString() String
A string representation of this object.
inherited
write(D value, ByteData buffer, int offset) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited