FfiConverterBool class

Constructors

FfiConverterBool()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocationSize([bool value = false]) int
lift(int value) bool
lower(bool value) int
lowerIntoRustBuffer(bool value) RustBuffer
read(Uint8List buf) LiftRetVal<bool>
write(bool value, Uint8List buf) int