FfiConverterFeeRateException class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
allocationSize(
FeeRateException value) → int -
lift(
RustBuffer buffer) → FeeRateException -
lower(
FeeRateException value) → RustBuffer -
read(
Uint8List buf) → LiftRetVal< FeeRateException> -
write(
FeeRateException value, Uint8List buf) → int