FfiConverterSequenceTxOut class

Constructors

FfiConverterSequenceTxOut()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocationSize(List<TxOut> value) int
lift(RustBuffer buf) List<TxOut>
lower(List<TxOut> value) RustBuffer
read(Uint8List buf) LiftRetVal<List<TxOut>>
write(List<TxOut> value, Uint8List buf) int