FfiConverterString class

Constructors

FfiConverterString()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocationSize([String value = ""]) int
lift(RustBuffer buf) String
lower(String value) RustBuffer
read(Uint8List buf) LiftRetVal<String>
write(String value, Uint8List buf) int