FfiConverterUInt32 class

Constructors

FfiConverterUInt32()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocationSize([int value = 0]) int
lift(int value) int
lower(int value) int
read(Uint8List buf) LiftRetVal<int>
write(int value, Uint8List buf) int