FfiConverterUint8List class

Constructors

FfiConverterUint8List()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocationSize([Uint8List? value]) int
lift(RustBuffer value) Uint8List
lower(Uint8List value) RustBuffer
read(Uint8List buf) LiftRetVal<Uint8List>
write(Uint8List value, Uint8List buf) int