InvalidChecksumEncodeException class

Inheritance

Constructors

InvalidChecksumEncodeException({required String expected, required String actual})

Properties

actual String
final
expected String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocationSize() int
override
lower() RustBuffer
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
write(Uint8List buf) int
override

Operators

operator ==(Object other) bool
The equality operator.
inherited