LiftRetVal<T> class

Constructors

LiftRetVal(T value, int bytesRead)
const

Properties

bytesRead int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

copyWithOffset(int offset) LiftRetVal<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited