Psbt class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

combine(Psbt other) Psbt
dispose() → void
extractTx() Transaction
fee() Amount
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
serializeBase64() String
serializeHex() String
toString() String
A string representation of this object.
inherited
uniffiClonePointer() Pointer<Void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocationSize(Psbt value) int
lower(Psbt value) Pointer<Void>
read(Uint8List buf) LiftRetVal<Psbt>
write(Psbt value, Uint8List buf) int