PsbtException class abstract
- Implemented types
- Implementers
- CombineInconsistentKeySourcesPsbtException
- ConsensusEncodingPsbtException
- DuplicateKeyPsbtException
- FeeOverflowPsbtException
- InvalidControlBlockPsbtException
- InvalidEcdsaSignaturePsbtException
- InvalidHashPsbtException
- InvalidKeyPsbtException
- InvalidLeafVersionPsbtException
- InvalidMagicPsbtException
- InvalidPreimageHashPairPsbtException
- InvalidProprietaryKeyPsbtException
- InvalidPublicKeyPsbtException
- InvalidSecp256k1PublicKeyPsbtException
- InvalidSeparatorPsbtException
- InvalidTaprootSignaturePsbtException
- InvalidXOnlyPublicKeyPsbtException
- IoPsbtException
- MissingUtxoPsbtException
- MustHaveUnsignedTxPsbtException
- NegativeFeePsbtException
- NoMorePairsPsbtException
- NonStandardSighashTypePsbtException
- OtherPsbtErrPsbtException
- PartialDataConsumptionPsbtException
- PsbtUtxoOutOfBoundsPsbtException
- TaprootPsbtException
- TapTreePsbtException
- UnexpectedUnsignedTxPsbtException
- UnsignedTxHasScriptSigsPsbtException
- UnsignedTxHasScriptWitnessesPsbtException
- VersionPsbtException
- XPubKeyPsbtException
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allocationSize(
) → int -
lower(
) → RustBuffer -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
Uint8List buf) → int
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited