Script class
Constructors
- Script(Uint8List rawOutputScript)
-
Script.lift(Pointer<
Void> ptr) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List -
toString(
) → String -
A string representation of this object.
inherited
-
uniffiClonePointer(
) → Pointer< Void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited