toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  switch (errorCode) {
    case bufferOverflow:
      return "UniFfi::BufferOverflow";
    case incompleteData:
      return "UniFfi::IncompleteData";
    case unexpectedOptionalTag:
      return "UniFfi::UnexpectedOptionalTag";
    case unexpectedEnumCase:
      return "UniFfi::UnexpectedEnumCase";
    case unexpectedNullPointer:
      return "UniFfi::UnexpectedNullPointer";
    case unexpectedRustCallStatusCode:
      return "UniFfi::UnexpectedRustCallStatusCode";
    case unexpectedRustCallError:
      return "UniFfi::UnexpectedRustCallError";
    case unexpectedStaleHandle:
      return "UniFfi::UnexpectedStaleHandle";
    case rustPanic:
      return "UniFfi::rustPanic: $panicMessage";
    default:
      return "UniFfi::UnknownError: $errorCode";
  }
}