Psbt class
Constructors
- Psbt.deserialize(Uint8List psbtBytes)
- Psbt.deserializeBase64(String psbtBase64)
- Psbt.fromUnsignedTx(Transaction tx)
-
Psbt.lift(Pointer<
Void> ptr) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
combine(
Psbt other) → Psbt -
dispose(
) → void -
extractTx(
) → Transaction -
fee(
) → Amount -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
serializeBase64(
) → String -
serializeHex(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
uniffiClonePointer(
) → Pointer< Void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited