Transaction class
Constructors
- Transaction.deserialize(Uint8List transactionBytes)
-
Transaction.lift(Pointer<
Void> ptr) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeTxid(
) → String -
dispose(
) → void -
input(
) → List< TxIn> -
isCoinbase(
) → bool -
isExplicitlyRbf(
) → bool -
isLockTimeEnabled(
) → bool -
lockTime(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
output(
) → List< TxOut> -
serialize(
) → Uint8List -
toString(
) → String -
A string representation of this object.
inherited
-
totalSize(
) → int -
uniffiClonePointer(
) → Pointer< Void> -
version(
) → int -
vsize(
) → int -
weight(
) → int
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
allocationSize(
Transaction value) → int -
lower(
Transaction value) → Pointer< Void> -
read(
Uint8List buf) → LiftRetVal< Transaction> -
write(
Transaction value, Uint8List buf) → int